﻿using HarmonyLib;
using System.Collections.Generic;
using System.Linq;
using Vintagestory.API.Common;
using Vintagestory.GameContent;

namespace AurorasClasses.classes;

[HarmonyPatch]
public class Blacksmith
{
    public static List<CharacterClass> CharacterClasses = new()
    {
        new CharacterClass()
        {
            Code = "blacksmith",
            Gear = new JsonItemStack[]
            {
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-neck-copper-torc"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-upperbody-raw-hide-mantle"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-shoulder-blacksmith-apron"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-waist-heavy-tool-belt"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-lowerbody-workmans-gown"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-foot-high-leather-boots"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-arm-leather-bracers"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-face-leather-reinforced-mask"),
                }
            },
            Traits = new []
            {
                "tinkerer", "heavyhanded", "merciless", "strong", "mender", "ravenous", "bulky"
            }
        },
    };

    public static List<Trait> traits = new()
    {
       
        new Trait
        {
            Code = "strong",
            Attributes = new Dictionary<string, double>() {
                {"maxhealthExtraPoints", 5},
                {"miningSpeedMul", 0.2},
                {"meleeWeaponsDamage", 0.25}
            },
            Type = EnumTraitType.Positive
        },
        new Trait
        {
            Code = "bulky",
            Attributes = new Dictionary<string, double>() {
                {"walkspeed", -0.2},
                {"bowDrawingStrength", -0.15 }
            },
            Type = EnumTraitType.Negative
        },
    };

    [HarmonyPostfix]
    [HarmonyPatch(typeof(CharacterSystem), "loadCharacterClasses")]
    public static void ShowCharacterClasses(CharacterSystem __instance)
    {
        foreach (var trait in traits.Where(trait => !__instance.traits.Contains(trait)))
        {
            __instance.traits.Add(trait);
            __instance.TraitsByCode[trait.Code] = trait;
        }

        foreach (var characterClass in CharacterClasses.Where(characterClass => !__instance.characterClasses.Contains(characterClass)))
        {
            __instance.characterClasses.Add(characterClass);
            __instance.characterClassesByCode[characterClass.Code] = characterClass;
        }
    }
}