﻿using HarmonyLib;
using System.Collections.Generic;
using System.Linq;
using Vintagestory.API.Common;
using Vintagestory.GameContent;

namespace AurorasClasses.classes;

[HarmonyPatch]
public class Merchant
{
    public static List<CharacterClass> CharacterClasses = new()
    {
        new CharacterClass()
        {
            Code = "merchant",
            Gear = new JsonItemStack[]
            {
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-head-merchant-hat"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-upperbody-merchant-shirt"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-upperbodyover-spice-merchants-coat"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-waist-merchant-belt"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-lowerbody-merchant-pants"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-foot-merchant-shoes"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-arm-merchant-bracelet"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-face-glasses"),
                },
                new()
                {
                    Type = EnumItemClass.Item,
                    Code = new AssetLocation("game", "clothes-neck-merchant-amulet"),
                }
            },
            Traits = new []
            {
                "businessman", "athletic", "furtive", "mender", "nearsighted", "soft-handed"
            }
        },
    };

    public static List<Trait> traits = new()
    {
        new Trait
        {
            Code = "businessman",
            Attributes = new Dictionary<string, double>() {
                {"rustyGearDropRate", 0.3}
            },
            Type = EnumTraitType.Positive
        },
        new Trait
        {
            Code = "athletic",
            Attributes = new Dictionary<string, double>() {
                {"maxhealthExtraPoints", 2},
                {"walkspeed", 0.2 },
                {"meleeWeaponsDamage", 0.15 }
            },
            Type = EnumTraitType.Positive
        },
        new Trait
        {
            Code = "soft-handed",
            Attributes = new Dictionary<string, double>() {
                {"miningSpeedMul", -0.15},
                {"oreDropRate", -0.2},
                {"animalHarvestingTime", -0.1},
                {"forageDropRate", -0.1},
                {"wildCropDropRate", -0.1}
            },
            Type = EnumTraitType.Negative
        },
    };

    [HarmonyPostfix]
    [HarmonyPatch(typeof(CharacterSystem), "loadCharacterClasses")]
    public static void ShowCharacterClasses(CharacterSystem __instance)
    {
        foreach (var trait in traits.Where(trait => !__instance.traits.Contains(trait)))
        {
            __instance.traits.Add(trait);
            __instance.TraitsByCode[trait.Code] = trait;
        }

        foreach (var characterClass in CharacterClasses.Where(characterClass => !__instance.characterClasses.Contains(characterClass)))
        {
            __instance.characterClasses.Add(characterClass);
            __instance.characterClassesByCode[characterClass.Code] = characterClass;
        }
    }
}